Internal function that calculates the ARL using the connection between the ARL of a Wald SPRT and a CUSUM.
bernoulli_ARL_SPRT(h, n_grid, Wncdf, glmmod, theta, theta_true, p0,
tol = 1e-06)Control limit for the Bernoulli CUSUM
Number of state spaces used to discretize the outcome space (when method = "MC")
or number of grid points used for trapezoidal integration (when method = "SPRT").
Increasing this number improves accuracy, but can also significantly increase computation time.
A function returning the values of the (risk-adjusted) cumulative distribution function (cdf) for the singletons Wn.
Generalized linear regression model used for risk-adjustment as produced by
the function glm(). Suggested:
glm(as.formula("(survtime <= followup) & (censorid == 1) ~ covariates"), data = data).
Alternatively, a list containing the following elements:
formula:a formula() in the form ~ covariates;
coefficients:a named vector specifying risk adjustment coefficients
for covariates. Names must be the same as in formula and colnames of data.
The \(\theta\) value used to specify the odds ratio \(e^\theta\) under the alternative hypothesis. If \(\theta >= 0\), the average run length for the upper one-sided Bernoulli CUSUM will be determined. If \(\theta < 0\), the average run length for the lower one-sided CUSUM will be determined. Note that $$p_1 = \frac{p_0 e^\theta}{1-p_0 +p_0 e^\theta}.$$
The true log odds ratio \(\theta\), describing the true increase in failure rate from the null-hypothesis. Default = log(1), indicating no increase in failure rate.
The baseline failure probability at entrytime + followup for individuals.