- data
A data.frame containing the following named columns for each subject:
entrytime:
time of entry into study (numeric);
survtime:
time from entry until event (numeric);
censorid:
censoring indicator (0 = right censored, 1 = observed)
(integer);
and optionally additional covariates used for risk-adjustment.
followup
The value of the follow-up time to be used to determine event time.
Event time will be equal to entrytime + followup for each subject.
glmmod
Generalized linear regression model used for risk-adjustment as produced by
the function glm(). Suggested:
glm(as.formula("(survtime <= followup) & (censorid == 1) ~ covariates"), data = data).
Alternatively, a list containing the following elements:
formula:
a formula() in the form ~ covariates;
coefficients:
a named vector specifying risk adjustment coefficients
for covariates. Names must be the same as in formula and colnames of data.
theta
The \(\theta\) value used to specify the odds ratio
\(e^\theta\) under the alternative hypothesis.
If \(\theta >= 0\), the chart will try to detect an increase
in hazard ratio (upper one-sided). If \(\theta < 0\),
the chart will look for a decrease in hazard ratio (lower one-sided).
Note that $$p_1 = \frac{p_0 e^\theta}{1-p_0 +p_0 e^\theta}.$$
p0
The baseline failure probability at entrytime + followup for individuals.
p1
The alternative hypothesis failure probability at entrytime + followup for individuals.
h
(optional): Control limit to be used for the procedure.
stoptime
(optional): Time after which the value of the chart should no longer be determined.
assist
(optional): Output of the function parameter_assist()
twosided
(optional): Should a two-sided Bernoulli CUSUM be constructed?
Default is FALSE.