Learn R Programming

success (version 1.0.1)

exp_hazards: Exponential hazard, cumulative hazard and inverse cumulative hazard

Description

Functions which return the hazard, cumulative hazard and inverse cumulative hazard at time t for an exponential distribution with parameter \(\lambda\) and true hazard ratio \(\mu\).

Usage

haz_exp(t, lambda, mu = log(1))

chaz_exp(t, lambda, mu = log(1))

inv_chaz_exp(t, lambda, mu = log(1))

Value

Value of specified function at time \(t\).

Arguments

t

time of evaluation.

lambda

parameter of the exponential distribution.

mu

(optional) true excess hazard rate \(\mu\).

Details

The hazard function of an exponential distribution is given by: $$h(t| \lambda, \mu) = \lambda e^\mu$$ The cumulative hazard (with true hazard ratio \(\mu\)) is given by: $$H(t| \lambda, \mu) = \lambda t e^\mu$$ The inverse cumulative hazard (with true hazard ratio \(\mu\)) by: $$H^{-1}(t| \lambda, \mu) = \frac{t}{\lambda e^\mu}$$